import React from "react";
import monacoForTypes, { editor } from "monaco-editor";
import { BaseMonacoEditor, ModelType } from "../types/monaco";
import CodeParser from "./codeParser";
export interface EditorInitState {
    editor: editor.IStandaloneCodeEditor | undefined;
    monaco: typeof monacoForTypes | undefined;
    models: ModelType[] | undefined;
    modelIndex: number | undefined;
    consoleMessages: any[];
    codeParser: CodeParser;
    codeParserInitLoading: boolean;
}
export interface EditorReducerActionType {
    type: "updateEditor" | "updateMonaco" | "updateModels" | "updateModelIndex" | "updateConsoleMessages" | "setCodeParser" | "updateCodeParserLoading";
    payload: Partial<EditorInitState>;
}
export declare type EditorReducerAction = {
    updateEditor: (e: BaseMonacoEditor) => void;
    updateMonaco: (m: typeof monacoForTypes) => void;
    updateModels: (m: ModelType[]) => void;
    updateModelIndex: (m: number) => void;
    updateConsoleMessages: (m: any[]) => void;
    setCodeParser: (m: any) => void;
    updateCodeParserLoading: (m: boolean) => void;
    cleanConsoleMessages: () => void;
    cleanModels: () => void;
};
export declare type EditorState = {
    state: EditorInitState;
    stateRef: React.MutableRefObject<EditorInitState>;
    dispatch: React.Dispatch<EditorReducerActionType>;
    actions: EditorReducerAction;
};
export declare function EditorProvider({ children }: {
    children: React.ReactNode;
}): JSX.Element;
export declare function useEditor(): EditorState;
